#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define libname acme
Name:           python-%{libname}
Version:        1.22.0
Release:        bp156.2.2
Summary:        Python library for the ACME protocol
License:        Apache-2.0
URL:            https://github.com/certbot/certbot
Source0:        https://files.pythonhosted.org/packages/source/a/%{libname}/%{libname}-%{version}.tar.gz
Source1:        https://files.pythonhosted.org/packages/source/a/%{libname}/%{libname}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  %{python_module cryptography >= 2.5.0}
BuildRequires:  %{python_module josepy >= 1.9.0}
BuildRequires:  %{python_module pyOpenSSL >= 17.3.0}
BuildRequires:  %{python_module pyRFC3339}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.14.2}
BuildRequires:  %{python_module requests-toolbelt >= 0.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography >= 2.5.0
Requires:       python-josepy >= 1.9.0
Requires:       python-pyOpenSSL >= 17.3.0
Requires:       python-pyRFC3339
Requires:       python-pytz
Requires:       python-requests >= 2.14.2
Requires:       python-requests-toolbelt >= 0.3.0
BuildArch:      noarch
%if %{?suse_version} < 1500
BuildRequires:  %{python_module devel}
%endif
%python_subpackages

%description
Python library implementing the Automatic Certificate Management Environment
(ACME) protocol. It is used by the certbot project. Formerly Let's Encrypt project.

%prep
%setup -q -n %{libname}-%{version}

%build
%python_build

%install
%python_install
# remove duplicates
%python_expand %fdupes %{buildroot}%{$python_sitelib}/%{libname}

%check
%pytest tests/

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/%{libname}
%{python_sitelib}/%{libname}-%{version}*.egg-info
%pycache_only %{python_sitelib}/%{libname}/__pycache__

%changelog
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 1.22.0
  * sync with main certbot package
- Refresh python-acme.keyring
* Mon Dec 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.0
  * The acme library now supports requesting certificates for
    IP addresses.
  * Removed the dependency on chardet from the library.
    Except for when downloading a certificate in an alternate format,
    the acme library now assumes all server responses are UTF-8
    encoded which is required by RFC 8555.
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with main certbot package
  * the .client.Client and .client.BackwardsCompatibleClientV2 classes
    are now deprecated in favor of .client.ClientV2
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * sync with main certbot package
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * sync with main certbot package
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * The module acme.magic_typing is deprecated and will be removed in
    a future release. Please use the built-in module typing instead.
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
  * The acme library no longer depends on the security extras from
    requests which was needed to support SNI in TLS requests when
    using old versions of Python 2.
  * When revoking a certificate by --cert-name, it is no longer
    necessary to specify the --server if the certificate was
    obtained from a non-default ACME server.
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  * We deprecated support for Python 2 in Certbot and its ACME
    library. Support for Python 2 will be removed in the next
    planned release of Certbot.
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * sync with the main certbot package
* Mon Sep 28 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 1.8.0
  * Support for Python 3.5 has been removed.
  * The acme library can now tell the ACME server to clear contact information by passing an empty
    tuple to the contact field of a Registration message.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * We deprecated support for Python 3.5 in Certbot and its ACME library.
    Support for Python 3.5 will be removed in the next major release of Certbot.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Support for alternative certificate chains in the acme module.
  * Added --preferred-chain <issuer CN>. If a CA offers multiple
    certificate chains, it may be used to indicate to Certbot which
    chain should be preferred.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Fix TLS-ALPN test that fails when run with newer versions of OpenSSL.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Added TLS-ALPN-01 challenge support in the acme library. Support of this
    challenge in the Certbot client is planned to be added in a future release.
  * mock dependency is now conditional on Python 2 in all of our packages.
  * When using an RFC 8555 compliant endpoint, the acme library no longer sends the
    resource field in any requests or the type field when responding to challenges.
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Don't verify the existing certificate in HTTP01Response.simple_verify, for
    compatibility with the real-world ACME challenge checks.
  * Fix acme module warnings when response Content-Type includes params (e.g. charset).
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Support for Python 3.4 has been removed.
  * Fix collections.abc imports for Python 3.9.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Removed the fallback introduced with 0.34.0 in acme to retry a POST-as-GET
    request as a GET request when the targeted ACME CA server seems to not support
    POST-as-GET requests.
  * Support for Python 3.4 in Certbot and its ACME library is deprecated and will be
    removed in the next release of Certbot.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0 (bsc#1160066)
  * Deprecated attributes related to the TLS-SNI-01 challenge in
    acme.challenges and acme.standalone have been removed.
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * acme.standalone.BaseRequestHandlerWithLogging and acme.standalone.simple_tls_sni_01_server
    have been deprecated and will be removed in a future release of the library.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * sync with main certbot package
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.37.2
  * acme: Authz deactivation added to acme module.
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * Added missing error types from RFC8555
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.35.1
  * sync with main certbot package
* Mon May 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use the %%pytest macro
* Sat May 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.2:
  * sync with main certbot package
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.32.0
  * Certbot and its acme module now depend on josepy>=1.1.0.
  * An ACME CA server may return a "Retry-After" HTTP header on
    authorization polling, as specified in the ACME protocol, to
    indicate when the next polling should occur. Certbot now reads
    this header if set and respect its value.
  * The acme module avoids sending the keyAuthorization field in
    the JWS payload when responding to a challenge as the field is
    not included in the current ACME protocol. To ease the migration
    path for ACME CA servers, Certbot and its acme module will first
    try the request without the keyAuthorization field but will
    temporarily retry the request with the field included if a
    malformed error is received. This fallback will be removed in
    version 0.34.0.
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.31.0
  * Support for initiating (but not solving end-to-end) TLS-ALPN-01
    challenges with the acme module.
  * Fixed accessing josepy contents through acme.jose when the full
    acme.jose path is used.
  * Added the update_account subcommand for account management commands.
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop pytest-xdist dependency as it is not really needed
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.30.2:
  * Remove josepy helpers that are no longer needed
* Sat Dec 15 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 0.29.1:
  * Release 0.29.1
  * Release 0.29.0
  * WIP External Account Binding (#6059)
  * Implement POST-as-GET requests (#6522)
  * ignore erroneously no-member lint error
  * Revert acme/acme/client.py
  * Bump version to 0.29.0
  * remove unused six imports
  * Remove module-level ignore::ResourceWarnings
  * bring requests back down to 2.4.1 in setup and oldest constraints
  * Requests no longer vendorizes urllib3
  * Use a newer version of requests because of the upcoming Callable import
    Deprecation in Python 3.8 that warns in Python 3.7
  * Cover is run on 2.7, so mark 3-only lines as no cover
  * Ignore ResourceWarnings in various modules in a 2-compatible way.
  * ignore ResourceWarnings in acme tests
  * s/assertEquals/assertEqual
- Adjust Requires
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * Use the ACMEv2 newNonce endpoint when a new nonce is needed, and
    newNonce is available in the directory.
  * Warn when using deprecated acme.challenges.TLSSNI01
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * acme client now raises an error when you try to create an ACME
    account with a key that has already been used
  * you can now call query_registration without having to first
    call new_account
* Tue Aug 28 2018 tchvatal@suse.com
- Reflect reality in the dependencies
- Run the tests
* Wed Jul 25 2018 ecsos@opensuse.org
- update to 0.26.1
  - No changelog from upstream
* Mon Jul 16 2018 ecsos@opensuse.org
- update to 0.26.0
  - No changelog from upstream
* Wed Jul  4 2018 ecsos@opensuse.org
- update to 0.25.1
  - No changelog from upstream
* Wed Jun 13 2018 ecsos@opensuse.org
- update to 0.25.0
  - No changelog from upstream
* Thu May  3 2018 ecsos@opensuse.org
- update to 0.24.0
  - No changelog from upstream
* Sat Apr 14 2018 ecsos@opensuse.org
- update to 0.23.0
  - No changelog from upstream
* Thu Mar 22 2018 ecsos@opensuse.org
- update to 0.22.2
  - No changelog from upstream
* Wed Mar 14 2018 ecsos@opensuse.org
- update to 0.22.0
  - No changelog from upstream
* Sat Jan 27 2018 ecsos@opensuse.org
- update to 0.21.1
  - No changelog from upstream
* Mon Dec 11 2017 ecsos@opensuse.org
- update to 0.20.0
  - No changelog from upstream
* Sat Oct  7 2017 ecsos@opensuse.org
- update to 0.19.0
  - No changelog from upstream
* Sat Sep 23 2017 ecsos@opensuse.org
- update to 0.18.2
  - No changelog from upstream
* Wed Sep 20 2017 ecsos@opensuse.org
- Convert to singlespec
* Mon Sep 11 2017 ecsos@opensuse.org
- update to 0.18.1
  - No changelog from upstream
* Fri Aug 11 2017 ecsos@opensuse.org
- update to 0.17.0
  - No changelog from upstream
* Fri Jul  7 2017 ecsos@opensuse.org
- update to 0.16.0
  - No changelog from upstream
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 0.15.0
  - No changelog from upstream
* Thu Jun  1 2017 ecsos@opensuse.org
- update to 0.14.2
  - No changelog from upstream
* Wed May 17 2017 ecsos@opensuse.org
- update to 0.14.1
  - No changelog from upstream
* Tue May 16 2017 ecsos@opensuse.org
- fix build error in Tumbleweed
* Mon May 15 2017 ecsos@opensuse.org
- update to 0.14.0
  - No changelog provides by upstream
* Tue Apr 25 2017 ecsos@opensuse.org
- update to 0.13.0
  - No changelog provides by upstream
* Mon Mar 27 2017 ecsos@opensuse.org
- insert BuildRequires: python-packaging to prevent build errors
  for Leap 42.1
* Mon Mar  6 2017 ecsos@opensuse.org
- change require version to python-requests >= 2.10
* Fri Mar  3 2017 ecsos@opensuse.org
- update to 0.12.0
  - No changelog provides by upstream
* Wed Feb  8 2017 ecsos@opensuse.org
- update to 0.11.1
  - No changelog provides by upstream
* Sat Jan 28 2017 ecsos@opensuse.org
- update to 0.10.2
  - No changelog provides by upstream
* Tue Jan 17 2017 ecsos@opensuse.org
- update to 0.10.1
  - No changelog provides by upstream
* Wed Jan 11 2017 ecsos@opensuse.org
- update to 0.10.0
  - No changelog provides by upstream
* Thu Oct 20 2016 ecsos@opensuse.org
- update to 0.9.3
  - No changelog provides by upstream
* Wed Oct  5 2016 ecsos@opensuse.org
- update to 0.9.0
  - No changelog provides by upstream
- drop patch acme-build-on-python-older-than-2_7.patch
* Sat Jun 18 2016 ecsos@opensuse.org
- update to 0.8.1
  - No changelog provides by upstream
* Sun Jun  5 2016 ecsos@opensuse.org
- update to 0.8.0
  - No changelog provided by upstream
- Drop fix-AttributeError-on-mock-older-than_2.0.patch because
  now in upstream
* Tue May 31 2016 ecsos@opensuse.org
- update to 0.7.0
  - No changelog provided by upstream
- add fix-AttributeError-on-mock-older-than_2.0.patch
* Fri May 13 2016 ecsos@opensuse.org
- update to 0.6.0
  - No changelog provided by upstream
- update Source with new pypi url
* Fri Apr  8 2016 ecsos@opensuse.org
- Update to version 0.5.0
  - No changelog provided by upstream
* Thu Mar 31 2016 ecsos@opensuse.org
- add BuildRequires python-setuptools >= 1.0
* Mon Mar  7 2016 ecsos@opensuse.org
- Update to version 0.4.2
  - No changelog provided by upstream
* Tue Mar  1 2016 ecsos@opensuse.org
- Update to version 0.4.1
  - No changelog provided by upstream
* Thu Feb 11 2016 jweberhofer@weberhofer.at
- Updated to version 0.4.0
  - No changelog provided by upstream
- updated requirement: python-pyOpenSSL >= 0.13
* Fri Jan 29 2016 jweberhofer@weberhofer.at
- Updated to version 0.3.0
  - No changelog provided by upstream
* Fri Jan 22 2016 jweberhofer@weberhofer.at
- Added python-mock requirement
* Fri Jan 15 2016 jweberhofer@weberhofer.at
- acme-build-on-python-older-than-2_7.patch allows building on
  python version < 2.7
* Fri Jan 15 2016 jweberhofer@weberhofer.at
- Updated to latest version 0.2.0
  - No changelog provided by upstream
* Thu Dec 17 2015 jweberhofer@weberhofer.at
- Fixed description and url
- Added group
* Thu Dec 17 2015 jweberhofer@weberhofer.at
- Initial version 0.1.1
